"""
############################################################################
##  global_options.py
##  
## Contains the Global Options which are accesible by all other classes.
## Note that all time options are in miliseconds.
############################################################################
"""
__all__ = [
    "game_options",             # global options instance 
                                # (accesible by all who include this module)
    ]

from    Opioid2D        import *
 

class GlobalOptions:

    def __init__(self):

        #### File Paths
        self.gfx_path       = 'graphics/'
        self.gfx_units_path = 'graphics/units'
        self.font_path      = 'fonts/'
        

        #### Buildings Options
        self.buildings   = {}   # A  dictionary of form:
                    #   'building name' -> A dictionary of form:
                    #       'buy_price'     -> Buy Price
                    #       'sell_price'    -> Sell Price
                    #       'discription'   -> Building text discription
                    #       'action_delay'  -> Delay (in mili-seconds) between 
                    #                          bilding actions
                    #       'max_health'    -> Maximum damage it can take
        ## 1- Barack
        self.buildings['barak']                         = {}
        self.buildings['barak']['buy_price']            = 200
        self.buildings['barak']['sell_price']           = -100
        self.buildings['barak']['discription']          = "Buy Barak [$%d]. Builds Infantry." 
        self.buildings['barak']['action_delay']         = 10000
        self.buildings['barak']['max_health']           = 1000
        self.buildings['barak']['maintence_chrg']       = 0  # The amount building charges per money cycle
        ## 2- Factory
        self.buildings['factory']                       = {}
        self.buildings['factory']['buy_price']          = 500
        self.buildings['factory']['sell_price']         = -200
        self.buildings['factory']['discription']        = "Buy Factory [$%d]. Builds Tank." 
        self.buildings['factory']['action_delay']       = 9000
        self.buildings['factory']['max_health']         = 2000
        self.buildings['factory']['maintence_chrg']     = 0  # The amount building charges per money cycle
        ## 3- Refinery
        self.buildings['refinery']                      = {}
        self.buildings['refinery']['buy_price']         = 400
        self.buildings['refinery']['sell_price']        = -200
        self.buildings['refinery']['discription']       = "Buy Refinery [$%d]. Generates Money." 
        self.buildings['refinery']['action_delay']      = None # refinary has no repeating action
        self.buildings['refinery']['max_health']        = 2000
        self.buildings['refinery']['maintence_chrg']    = 0  # The amount building charges per money cycle        
        self.buildings['refinery']['money_per_cycle']   = 100
        self.buildings['refinery']['multiple_effect']   = 2.5   
        # multiple_effect determines how much more money you get for each extra 
        # refimary you build. For instance with multiple_effect=2.5, if the 
        # first refinary gives $100/cycle, the second one will give $250 and 
        # the third one will give $625
        ## Turret
        self.buildings['turret']                        = {}
        self.buildings['turret']['buy_price']           = 400
        self.buildings['turret']['sell_price']          = -200
        self.buildings['turret']['discription']         = "Buy Turret [$%d]. Defends Your Base." 
        self.buildings['turret']['action_delay']        = 3000
        self.buildings['turret']['max_health']          = 1000
        self.buildings['turret']['maintence_chrg']  = 10  # The amount building charges per money cycle
        self.buildings['turret']['hitpoint']            = 200
        self.buildings['turret']['fire_range']          = 200
        self.buildings['turret']['num_targets']         = 3   # Number of targets to attack simoltaneously
        
        
        ## //TODO: The rest of the buildings
        
        #### Player Options
        self.player  = {}    # A dictionary of form:
                    #   [side] (e.g. 'right', 'left) -> A dictionary of 
                    #                                  different player options
        self.player['right']                        = {}
        self.player['right']['color']               = {}
        self.player['right']['color']['normal']     = (0.0, 0.0, 1.0)
        self.player['right']['color']['highlight']  = (1.0, 0.0, 1.0)
        self.player['right']['color']['selected']   = (0.5, 0.5, 1.0)     
        self.player['right']['color']['units']      = (0.5, 0.2, 1.0)     
        self.player['left']                         = {}
        self.player['left']['color']                = {}
        self.player['left']['color']['normal']      = (0.0, 0.6, 0.0)
        self.player['left']['color']['highlight']   = (0.0, 1.0, 0.0)
        self.player['left']['color']['selected']    = (0.5, 8.0, 0.5)
        self.player['left']['color']['units']       = (0.5, 1.0, 0.2)     
        self.gui_player_side    = 'left'    # The side of the GUI Player
        self.ai_player_side     = 'right'   # The side of the AI Player
        
        #### Unit Options
        # TODO: create a seperate action delay for each unit
        self.unit_action_delay              = 1500  # Number of milisecodns between 
                                                    # units' action update
        self.unit_initial_march             = (100, 0)  # The movement when built
        self.units                          = {}        # General options for each unit
        self.units['tank']                  = {}
        self.units['tank']['price']         = 500
        self.units['tank']['max_helath']    = 500
        self.units['tank']['speed']         = 50
        self.units['tank']['hitpoint']      = 100
        self.units['tank']['fire_range']    = 150
        self.units['infantry']              = {}
        self.units['infantry']['price']     = 200
        self.units['infantry']['max_helath']= 200
        self.units['infantry']['speed']     = 20
        self.units['infantry']['hitpoint']  = 50
        self.units['infantry']['fire_range']= 100
        
        
        #### Game Play Options
        self.players_initial_money      = 20000  # Initial money of the players
        self.pay_cycle_delay            = 1000  # miliseconds between pay cycle
        #### GUI Optios
        self.win_width                  = 800   # Game Window Width
        self.win_height                 = 600   # Game Window height
        self.panel_width                = 800   # Width of the main panel
        self.panel_height               = 80    # Height of the main panel
        self.button_colors              = {}    # Color options for buttons
        self.button_colors['normal']    = (0.7, 0.7,0.7)
        self.button_colors['highlight'] = (1.0, 1.0,1.0)
        self.button_colors['disabled']  = (1.0, 0.2,0.2)
        self.buy_button                 = {}    # Options for buy-buttons 
        self.buy_button['dist_bottom']  = 5     # distance from bottom of panel
        self.buy_button['dist_left']    = 220   # distance from left of panel
        self.buy_button['dist_between'] = 70    # distance between buy-buttons
        self.lot_pos                    = {}            # A dictionary to  
        self.lot_pos[0]                 =   (70, 180)   # define lot positions
        self.lot_pos[1]                 =   (140, 260)  # Note that we define
        self.lot_pos[2]                 =   (70, 340)   # positions for left 
        self.lot_pos[3]                 =   (140, 420)  # lots here, and the 
        self.lot_pos[4]                 =   (70, 500) # right lots are mirrored 
        self.status_bar_money_format    = " $%d (+%d/cycle) " # $2000 (+25/cycle)
        
        #### Misc Options
        self.building_scale         = 0.7   # the scale of all buildings 
        self.unit_scale             = 0.8   # the scale of all units
        self.lot_alpha              = 0.7   # make lots look integrated with bg
        self.callback_ignore        = 5     # 40 times this value is the number 
                                            # of miliseconds between gamecycles
                                            # A value of 1 (delay of 40ms) will
                                            # give 25 cycles per second. 
                                            # A velue of 5 (delay of 200ms) 
                                            # will give 5 cycles per second.
        
        #### Convert all time intervals to seconds
        self.unit_action_delay  = float(self.unit_action_delay) / 1000.0
        # TODO: do the same for other time intervals
game_options = GlobalOptions()