"""
############################################################################
##  main_scene.py
##  
## This is the main class of the game. 
## Most of the game objects are created here. It all happens here baby!
############################################################################
"""

from    Opioid2D        import *
from    global_options  import game_options
from    panels          import PanelManager
from    lots            import init_lots
from    players         import GUIPlayer, AIPlayer
from    misc_gui_parts  import StatusBar

class MainScene(Scene):
    # Define the game layers. The layers are sorted based on their order here
    layers = [  'backgroud',
                'gui_panels',
                'gui_buttons',
                'gui_text',
                'lots',
                'buildings',
                'units',
                'bullets',
                'particles' ]
    # The game also has a number of groups that are used for collision 
    # detection and other calculations
    # The groups are: 
    #   live_buildings_left
    #   live_buildings_right
    #   live_units_left
    #   live_units_right
    
    panel_manager   = None  # panel manager is resposible for managing/showing 
                            # the main panel
    background      = None  # The background sprite
    status_bar      = None  # the StatusBar
    player_gui      = None  # The GUI player
    player_ai       = None  # The AI Player
    
    def enter(self):
        """
            Initlizes the game. (This method is called before the game starts)
        """
        
        # Load the Background
        self.background = Sprite(game_options.gfx_path + "bg.png")
        self.background.set(layer = "backgroud", position=(400,300))
        
        # Load the Main Panel
        self.panel_manager = PanelManager()
        self.panel_manager.set_current_panel('main_panel')  
        
        # Initlize players
        self.player_gui = GUIPlayer(game_options.gui_player_side, 
                                    game_options.players_initial_money)
        init_lots(self.player_gui, is_locked = False)  # init player's lots
        self.player_ai  = AIPlayer( game_options.ai_player_side, 
                                    game_options.players_initial_money)
        init_lots(self.player_ai, is_locked = False)  # init player's lots
        
        # Load the StatusBar
        self.status_bar = StatusBar(self.player_gui, self.player_ai)
        
        
        self.ignored_callbacks = 0  #counts how many call backs we have ignored

        
    def realtick(self):
        """
            This is called 25 times per second regardless of the frame-rate
            It will call our game_cycle method based on how many call backs
            we is should ignore (set in global_options)
        """
        self.ignored_callbacks = self.ignored_callbacks + 1
        if self.ignored_callbacks == game_options.callback_ignore:
            self.game_cycle()
            self.ignored_callbacks = 0
        else:
            self.ignored_callbacks = self.ignored_callbacks + 1
            
    
    
    def game_cycle(self):
        """
            This is the main game-cycle. It is called with a constant frequency
            regardless to the framerate. it is here, that we carry players' 
            actions
        """
        # Update players Money
        # self.player_gui.update_money()
        # self.player_ai.update_money()
        