"""
############################################################################
##  misc_gui_parts.py
##  
## Contains bits and parts of the GUI that don't have their own file
## Currently it holds the StatusBar class
############################################################################
"""
from    Opioid2D        import *
from    global_options  import game_options
from    sys             import exit

class StatusBar(Sprite):
    """
        #######################################################################
        ## This is the StatusBar show at the bottom of the screen
        ## note that anytime players' money or money growth changes,
        ## statusbar's update method should be called
        ##
        ## Object Variables:
        ##  left_player                 # Player on the left
        ##  right_player                # Player on the right
        ##  left_plyr_money_txt_sprite  # Sprite showing player's money message
        ##  right_plyr_money_txt_sprite # Sprite showing player's money message   
        ##  font                        # font object to write players' money
        #######################################################################
    """
    layer   = 'gui_panels'
    image   = game_options.gfx_path + "status_bar.png"
    

    def __init__(self, player1, player2):
        Sprite.__init__(self)
        if player1.side == 'right':
            self.right_player   = player1
            self.left_player    = player2
        elif player1.side == 'left':
            self.right_player   = player2
            self.left_player    = player1
        else:
            exit("Unknown player side" + player1.side)
        # put the status bar athe bottom of teh screen
        self.rect.bottomleft = Director.scene.background.rect.bottomleft
        # initlize the font
        self.font = BitmapFont(game_options.font_path + "font_small.o2f")
        # update the money texts
        self.right_plyr_money_txt_sprite    = None
        self.left_plyr_money_txt_sprite     = None
        self.update()
        
    def update(self):
        """
            Updates player's money and money growth text
            This method should be called anytime a player's money or money
            growth changes
        """
        # Delete the previous text sprites
        if self.left_plyr_money_txt_sprite  is not None:
            self.left_plyr_money_txt_sprite.delete()
        if self.right_plyr_money_txt_sprite  is not None:
            self.right_plyr_money_txt_sprite.delete()
        # Create the new text sprites
        left_player_text = game_options.status_bar_money_format % (
                                self.left_player.money, 
                                self.left_player.money_growth   )
        self.left_plyr_money_txt_sprite = self.font.create( left_player_text, 
                                                            single=True)
        self.left_plyr_money_txt_sprite.set(layer="gui_text")
        self.left_plyr_money_txt_sprite.rect.bottomleft = self.rect.bottomleft
        
        right_player_text = game_options.status_bar_money_format % (
                                self.right_player.money, 
                                self.right_player.money_growth   )
        self.right_plyr_money_txt_sprite = self.font.create( right_player_text, 
                                                            single=True)
        self.right_plyr_money_txt_sprite.set(layer="gui_text")
        self.right_plyr_money_txt_sprite.rect.bottomright = self.rect.bottomright
