"""
############################################################################
##  targetables.py
##  
## Contains different unit classes (like tanks, infintry, etc).
############################################################################
"""

from    sys     import exit

class Targetable(object):
    """
        #######################################################################
        ## This is the superclass of all 'targetable' objects in the game, i.e. 
        ## objects that can be hit and destroyed (like buildings and units)
        ## 
        ## Object Variables:
        ##  uid         Unique ID
        ##  health      Current health of the object
        ##  max_health  Maximum health of the object
        ##  is_alive    True when the unit is alive
        #######################################################################
    """
    global get_next_uid # global module function, which generates UID's
    
    def __init__(self, max_health):
        """
            Constructor
        """
        self.uid        = get_next_uid()
        self.max_health = max_health
        self.health     = max_health
        self.is_alive   = True
        
    def get_hit(self, hit_points):
        """
            Called when the object is hit by another object
        """
        self._show_anim_hit()
        self.health = self.health - hit_points
        print self.side, self.health
        if self.health <= 0:
            self._show_anim_die()
            self.is_alive = False
            self.die()
    
    def die(self):
        """
            Called when the object dies
        """
        exit("Targetable::Die must be overridden by the subclass")
    
    def _show_anim_hit(self):
        """
            Shows an animation when the unit is hit.
            Must be implemented by derived classes
        """
        pass
    
    def _show_anim_die(self):
        """
            Shows an animation when the unit dies
            Must be implemented by derived classes
        """
        pass

next_uid = 1000    # Keeps the next unique id
def get_next_uid():
    """
        Generates the next unique ID
    """
    global next_uid
    next_uid = next_uid + 1
    return next_uid 